@@ -14,8 +14,6 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-    
-    $Id: tap_eqbw.c,v 1.6 2009/08/17 11:16:19 tszilagyi Exp $
 */
 
 
@@ -27,7 +25,7 @@
 #include <string.h>
 #include <math.h>
 
-#include "ladspa.h"
+#include <ladspa.h>
 #include "tap_utils.h"
 
 /* The Unique ID of the plugin */
@@ -167,7 +165,8 @@ activate_eq(LADSPA_Handle instance) {
 static
 void
 cleanup_eq(LADSPA_Handle instance) {
-
+	eq *plugin_data = (eq *)instance;
+	free(plugin_data->filters);
 	free(instance);
 }
 
@@ -596,7 +595,7 @@ run_adding_eq(LADSPA_Handle instance, unsigned long sample_count) {
 
 
 void
-_init() {
+__attribute__((constructor)) tap_init() {
 
 	char **port_names;
 	LADSPA_PortDescriptor *port_descriptors;
@@ -955,7 +954,7 @@ _init() {
 
 
 void 
-_fini() {
+__attribute__((destructor)) tap_fini() {
 
 	if (eqDescriptor) {
 		free((LADSPA_PortDescriptor *)eqDescriptor->PortDescriptors);
